@@ -252,7 +252,8 @@ impl <'a> PortfolioPerformanceAnalyser<'a> {
                     deposit_view.transaction(trade.conclusion_time, volume);
                     deposit_view.transaction(trade.conclusion_time, commission);
                 },
-                StockSource::CorporateAction => {
+
+                StockSource::CorporateAction | StockSource::Grant => {
                     self.get_deposit_view(&trade.symbol).trade(
                         &portfolio.name, &trade.symbol, trade.conclusion_time, quantity);
                 },
@@ -426,7 +427,7 @@ impl <'a> PortfolioPerformanceAnalyser<'a> {
     }
 
     fn process_cash_assets(&mut self, statement: &BrokerStatement) -> EmptyResult {
-        self.current_assets += statement.cash_assets.total_assets_real_time(
+        self.current_assets += statement.assets.cash.total_assets_real_time(
             self.currency, self.converter)?;
         Ok(())
     }
